# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing_extensions
from ..core.serialization import FieldMetadata
import pydantic
import typing
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class ExternalProfileV1(UniversalBaseModel):
    profile_id: typing_extensions.Annotated[str, FieldMetadata(alias="profileId")] = pydantic.Field()
    """
    Id of the profile.
    """

    status: typing.Optional[str] = pydantic.Field(default=None)
    """
    Status of the profile.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
