# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing_extensions
from ..core.serialization import FieldMetadata
import typing
from .issue import Issue
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ErrorEnvelope(UniversalBaseModel):
    http_status: typing_extensions.Annotated[int, FieldMetadata(alias="HttpStatus")]
    message: typing_extensions.Annotated[str, FieldMetadata(alias="Message")]
    data: typing.Optional[typing.Any] = None
    errors: typing.Optional[typing.List[Issue]] = None
    meta: typing.Optional[typing.Any] = None
    warnings: typing.Optional[typing.List[Issue]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
